@@ -9,7 +9,7 @@ from spei.utils import to_snake_case  # noqa: WPS347
 
 
 class ResultadoBanxico(BaseModel):
-    codigo: CodigoErrorAcuseBanxico
+    codigo: CodigoErrorAcuseBanxico = None
     descripcion: str = 'ND'
 
     class Config:  # noqa: WPS306, WPS431
@@ -24,25 +24,34 @@ class ResultadoServidor(BaseModel):
         use_enum_values = True
 
 
+class MensajeRespuesta(object):
+    def __new__(cls, mensaje):
+        return mensaje
+
+    @classmethod
+    def parse_xml(cls, mensaje):
+        root_element = etree.fromstring(mensaje)  # noqa: S320
+
+        body_element = root_element.find(
+            '{http://schemas.xmlsoap.org/soap/envelope/}Body',
+        )
+        return cls(
+            mensaje=body_element.find('mensajeRespuestaCDA'),
+        )
+
+
 class Acuse(BaseModel):
     cda_id: str
     mensaje_id: str
     tipo_respuesta: TipoRespuestaAcuse
-    resultado_enlace_cep: ResultadoServidor = None
+    resultado_enlace_cep: ResultadoServidor
     resultado_banxico: ResultadoBanxico = None
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
 
     def build_xml(self):
-        qname = etree.QName('http://www.w3.org/2001/XMLSchema-instance', 'type')
-        mensaje = etree.Element(
-            'mensajeRespuestaCDA',
-            {qname: 'mensajeRespuestaCDA'},
-            tipoRespuesta=self.tipo_respuesta,
-        )
-        acuse = etree.SubElement(
-            mensaje,
+        acuse = etree.Element(
             'acuse',
             idCda=self.cda_id,
             idMensaje=self.mensaje_id,
@@ -55,6 +64,13 @@ class Acuse(BaseModel):
             descripcion=self.resultado_enlace_cep.descripcion,
         )
 
+        if not self.resultado_banxico:
+            etree.SubElement(
+                acuse,
+                'resultadoBanxico',
+            )
+            return acuse
+
         etree.SubElement(
             acuse,
             'resultadoBanxico',
@@ -62,7 +78,7 @@ class Acuse(BaseModel):
             descripcion=self.resultado_banxico.descripcion,
         )
 
-        return mensaje
+        return acuse
 
     @classmethod
     def parse_xml(cls, mensaje_element):
